ISettlementsController

Struct ISettlementsController 

pub struct ISettlementsController;
WebAPI controller Settlements.

Implementations

Source

impl ISettlementsController

pub async fn Get<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements

pub async fn GetRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements

pub async fn GetByDocument<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements

Parameter document_id: Id dokumentu.

pub async fn GetByDocumentRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements

Parameter document_id: Id dokumentu.

pub async fn GetListByIssueDate<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/ByIssueDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetListByIssueDateRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/ByIssueDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetListByMaturityDate<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/ByMaturityDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetListByMaturityDateRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/ByMaturityDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetNotSettledByIssueDate<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/NotSettled/ByIssueDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetNotSettledByIssueDateRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/NotSettled/ByIssueDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetNotSettledByMaturityDate<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/NotSettled/ByMaturityDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetNotSettledByMaturityDateRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

GET /api/Settlements/Filter/NotSettled/ByMaturityDate

Parameter date_from: Data od przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki do wskazanej daty do. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

Parameter date_to: Data do przedziału czasowego. W przypadku, gdy parametr nie zostanie podany wyszukane zostaną wszystkie rozrachunki od wskazanej daty od. Data paramteru powinna zostać podana w formacie yyyy-MM-dd.

pub async fn GetNotSettled( api: &ApiClient, ) -> Result<ResponseEnvelope<Vec<SettlementListElement>>, ApiError>

GET /api/Settlements/Filter/NotSettled

pub async fn GetNotSettledRaw( api: &ApiClient, ) -> Result<ResponseEnvelope<Value>, ApiError>

GET /api/Settlements/Filter/NotSettled

pub async fn Issue( api: &ApiClient, settlement: &SettlementIssue, ) -> Result<ResponseEnvelope<Settlement>, ApiError>

POST /api/Settlements/Issue

Body settlement: Obiekt dokumentu rozrachunku do wystawienia.

pub async fn IssueRaw( api: &ApiClient, settlement: &SettlementIssue, ) -> Result<ResponseEnvelope<Value>, ApiError>

POST /api/Settlements/Issue

Body settlement: Obiekt dokumentu rozrachunku do wystawienia.