IPurchasesIssueController

Struct IPurchasesIssueController 

pub struct IPurchasesIssueController;
WebAPI controller PurchasesIssue.

Implementations

Source

impl IPurchasesIssueController

pub async fn AddNew<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

POST /api/PurchasesIssue/New

Parameter issue: Czy wystawić dokument zakupu. W przypadku, gdy parametr nie zostanie podany dokument zakupu zostanie dodany do bufora.

Body document: Obiekt dokumentu zakupu do dodania do bufora lub wystawienia.

pub async fn AddNewRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

POST /api/PurchasesIssue/New

Parameter issue: Czy wystawić dokument zakupu. W przypadku, gdy parametr nie zostanie podany dokument zakupu zostanie dodany do bufora.

Body document: Obiekt dokumentu zakupu do dodania do bufora lub wystawienia.

pub async fn Issue<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/InBuffer

Parameter id: Id dokumentu zakupu.

pub async fn IssueRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/InBuffer

Parameter id: Id dokumentu zakupu.

pub async fn IssuePZ<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/PZ

Parameter document_id: Id dokumentu zakupu.

pub async fn IssuePZRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/PZ

Parameter document_id: Id dokumentu zakupu.

pub async fn IssuePZCorrection<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<T::Output>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/PZCorrection

Parameter document_id: Id dokumentu zakupu.

Parameter issue: Jeżeli to możliwe, czy wystawić korekty dokumentów magazynowych. W przypadku, gdy parametr nie zostanie podany korekty dokumentów magazynowych zostaną dodane do bufora.

pub async fn IssuePZCorrectionRaw<T>( api: &ApiClient, overload: T, ) -> Result<ResponseEnvelope<Value>, ApiError>
where T: Overload,

PUT /api/PurchasesIssue/PZCorrection

Parameter document_id: Id dokumentu zakupu.

Parameter issue: Jeżeli to możliwe, czy wystawić korekty dokumentów magazynowych. W przypadku, gdy parametr nie zostanie podany korekty dokumentów magazynowych zostaną dodane do bufora.

pub async fn ChangeDocumentNumber( api: &ApiClient, id: i32, number: String, ) -> Result<ResponseEnvelope<()>, ApiError>

PATCH /api/PurchasesIssue/DocumentNumber

Parameter id: Id dokumentu zakupu.

Parameter number: Nowy numer dokumentu zakupu.

pub async fn ChangeDocumentNumberRaw( api: &ApiClient, id: i32, number: String, ) -> Result<ResponseEnvelope<Value>, ApiError>

PATCH /api/PurchasesIssue/DocumentNumber

Parameter id: Id dokumentu zakupu.

Parameter number: Nowy numer dokumentu zakupu.